==> ejc-riskmortgage-impl-3.0.0-20231129.014354-92-sources.jar: com/ejianc/business/share/bean/ShareDeptEntity.java <==
package com.ejianc.business.share.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分配—项目分配明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_share_dept")
public class ShareDeptEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="share_id")
    private Long shareId; // 主表id
    @TableField(value="payer_id")
    private Long payerId; // 员工表主键id
    @TableField(value="payer_code")
    private String payerCode; // 员工明细编号
    @TableField(value="payer_detail_id")
    private Long payerDetailId; // 员工明细表主键id
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="job")
    private String job; // 角色
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="payer_mny")
    private BigDecimal payerMny; // 缴纳金额（万元）
    @TableField(value="payer_scale")
    private BigDecimal payerScale; // 实际纳金额占比
    @TableField(value="actual_payer_mny")
    private BigDecimal actualPayerMny; // 实际已缴纳金额（万元）
    @TableField(value="share_dept_mny")
    private BigDecimal shareDeptMny; // 分配金额（万元）
    @TableField(value="share_dept_scale")
    private BigDecimal shareDeptScale; // 分配金额占比
    @TableField(value="memo")
    private String memo; // 备注
    
    
    

    public Long getShareId() {
        return shareId;
    }

    public void setShareId(Long shareId) {
        this.shareId = shareId;
    }
    public Long getPayerId() {
        return payerId;
    }

    public void setPayerId(Long payerId) {
        this.payerId = payerId;
    }
    public String getPayerCode() {
        return payerCode;
    }

    public void setPayerCode(String payerCode) {
        this.payerCode = payerCode;
    }
    public Long getPayerDetailId() {
        return payerDetailId;
    }

    public void setPayerDetailId(Long payerDetailId) {
        this.payerDetailId = payerDetailId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getPayerMny() {
        return payerMny;
    }

    public void setPayerMny(BigDecimal payerMny) {
        this.payerMny = payerMny;
    }
    public BigDecimal getPayerScale() {
        return payerScale;
    }

    public void setPayerScale(BigDecimal payerScale) {
        this.payerScale = payerScale;
    }
    public BigDecimal getActualPayerMny() {
        return actualPayerMny;
    }

    public void setActualPayerMny(BigDecimal actualPayerMny) {
        this.actualPayerMny = actualPayerMny;
    }
    public BigDecimal getShareDeptMny() {
        return shareDeptMny;
    }

    public void setShareDeptMny(BigDecimal shareDeptMny) {
        this.shareDeptMny = shareDeptMny;
    }
    public BigDecimal getShareDeptScale() {
        return shareDeptScale;
    }

    public void setShareDeptScale(BigDecimal shareDeptScale) {
        this.shareDeptScale = shareDeptScale;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}

==> ejc-riskmortgage-impl-3.0.0-20231205.095049-100-sources.jar: com/ejianc/business/share/bean/ShareDeptEntity.java <==
package com.ejianc.business.share.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 分配—项目分配明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_riskmortgage_share_dept")
public class ShareDeptEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="share_id")
    private Long shareId; // 主表id
    @TableField(value="payer_id")
    private Long payerId; // 员工表主键id
    @TableField(value="payer_code")
    private String payerCode; // 员工明细编号
    @TableField(value="payer_detail_id")
    private Long payerDetailId; // 员工明细表主键id
    @TableField(value="employee_id")
    private Long employeeId; // 人员id
    @TableField(value="name")
    private String name; // 姓名
    @TableField(value="job")
    private String job; // 角色
    @TableField(value="phone")
    private String phone; // 手机号
    @TableField(value="payer_mny")
    private BigDecimal payerMny; // 缴纳金额（万元）
    @TableField(value="payer_scale")
    private BigDecimal payerScale; // 实际纳金额占比
    @TableField(value="actual_payer_mny")
    private BigDecimal actualPayerMny; // 实际已缴纳金额（万元）
    @TableField(value="share_dept_mny")
    private BigDecimal shareDeptMny; // 分配金额（万元）
    @TableField(value="share_dept_scale")
    private BigDecimal shareDeptScale; // 分配金额占比
    @TableField(value="memo")
    private String memo; // 备注


    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public Long getShareId() {
        return shareId;
    }

    public void setShareId(Long shareId) {
        this.shareId = shareId;
    }
    public Long getPayerId() {
        return payerId;
    }

    public void setPayerId(Long payerId) {
        this.payerId = payerId;
    }
    public String getPayerCode() {
        return payerCode;
    }

    public void setPayerCode(String payerCode) {
        this.payerCode = payerCode;
    }
    public Long getPayerDetailId() {
        return payerDetailId;
    }

    public void setPayerDetailId(Long payerDetailId) {
        this.payerDetailId = payerDetailId;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getJob() {
        return job;
    }

    public void setJob(String job) {
        this.job = job;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public BigDecimal getPayerMny() {
        return payerMny;
    }

    public void setPayerMny(BigDecimal payerMny) {
        this.payerMny = payerMny;
    }
    public BigDecimal getPayerScale() {
        return payerScale;
    }

    public void setPayerScale(BigDecimal payerScale) {
        this.payerScale = payerScale;
    }
    public BigDecimal getActualPayerMny() {
        return actualPayerMny;
    }

    public void setActualPayerMny(BigDecimal actualPayerMny) {
        this.actualPayerMny = actualPayerMny;
    }
    public BigDecimal getShareDeptMny() {
        return shareDeptMny;
    }

    public void setShareDeptMny(BigDecimal shareDeptMny) {
        this.shareDeptMny = shareDeptMny;
    }
    public BigDecimal getShareDeptScale() {
        return shareDeptScale;
    }

    public void setShareDeptScale(BigDecimal shareDeptScale) {
        this.shareDeptScale = shareDeptScale;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    
}
